==> ember-bootstrap-2.8.0.tgz: package/README.md <==
# ember-bootstrap

[![Build Status](https://travis-ci.org/kaliber5/ember-bootstrap.svg?branch=master)](https://travis-ci.org/kaliber5/ember-bootstrap)
[![BrowserStack Status](https://www.browserstack.com/automate/badge.svg?badge_key=UzdFQU9hSW1FdjhLU3hDU0I3ZXF6WG1YSWp2TGRHaU9tYmhNT0pPdUNhQT0tLWZqTkNQUzBjNFUvcFhlWTA0YitETmc9PQ==--2f9e373be422d4fcc56c8d658afc55f1938a721e)](https://www.browserstack.com/automate/public-build/UzdFQU9hSW1FdjhLU3hDU0I3ZXF6WG1YSWp2TGRHaU9tYmhNT0pPdUNhQT0tLWZqTkNQUzBjNFUvcFhlWTA0YitETmc9PQ==--2f9e373be422d4fcc56c8d658afc55f1938a721e)
[![Ember Observer Score](http://emberobserver.com/badges/ember-bootstrap.svg)](http://emberobserver.com/addons/ember-bootstrap)
[![npm version](https://badge.fury.io/js/ember-bootstrap.svg)](https://badge.fury.io/js/ember-bootstrap)
[![Dependency Status](https://david-dm.org/kaliber5/ember-bootstrap.svg)](https://david-dm.org/kaliber5/ember-bootstrap)
[![devDependency Status](https://david-dm.org/kaliber5/ember-bootstrap/dev-status.svg)](https://david-dm.org/kaliber5/ember-bootstrap#info=devDependencies)
[![Greenkeeper badge](https://badges.greenkeeper.io/kaliber5/ember-bootstrap.svg)](https://greenkeeper.io/)

An [ember-cli](http://www.ember-cli.com) addon for using [Bootstrap](http://getbootstrap.com/) 3 or 4 in Ember applications.

The addon includes the Bootstrap CSS (or Sass, Less) in your project (can be disabled). On top of that, it provides a set of native Ember components (no use of Bootstrap JavaScript!).</p>

*See [www.ember-bootstrap.com](http://www.ember-bootstrap.com/) for full documentation.*

## Installation

In your application's directory:

    ember install ember-bootstrap
    
This will install Bootstrap 4 and will use the currently installed preprocessor or none if one is not installed.
To switch Bootstrap version or preprocessor, see the [setup documentation](http://www.ember-bootstrap.com/#/getting-started/setup).

## Compatibility

ember-bootstrap works and is fully [tested](https://travis-ci.org/kaliber5/ember-bootstrap) with

* Ember.js 2.3+
* Bootstrap 3 and 4.
* all modern evergreen browsers (Chrome, Firefox, Safari, Edge) and IE 11. 
* FastBoot 1.0+ 
* jQuery-less builds (using [ember-native-dom-event-dispatcher](https://github.com/rwjblue/ember-native-dom-event-dispatcher)
or Ember 3.x)

This project follows [Semantic Versioning](http://semver.org/).

## Updates

See [CHANGELOG](CHANGELOG.md) for the list of all changes.

If you want to keep up to date with ember-bootstrap, you may want to [follow me on Twitter](https://twitter.com/simonihmig). 

## Author and collaborators

* [Simon Ihmig](https://github.com/simonihmig)
* [Stephen Vance](https://github.com/srvance)
* and many more [contributors](https://github.com/kaliber5/ember-bootstrap/graphs/contributors)

## Contributing

See the [Contributing](CONTRIBUTING.md) guide for details.

## Credits

Cross-browser testing provided by:

<a href="https://www.browserstack.com"><img height="70" src="docs/Browserstack-logo.svg" alt="BrowserStack"></a>

## Copyright and license

Code and documentation copyright 2019 [kaliber5](http://www.kaliber5.de) and contributors. Code released under [the MIT license](LICENSE.md).

==> ember-bootstrap-3.1.4.tgz: package/README.md <==
# ember-bootstrap

[![Build Status](https://travis-ci.org/kaliber5/ember-bootstrap.svg?branch=master)](https://travis-ci.org/kaliber5/ember-bootstrap)
[![BrowserStack Status](https://www.browserstack.com/automate/badge.svg?badge_key=UzdFQU9hSW1FdjhLU3hDU0I3ZXF6WG1YSWp2TGRHaU9tYmhNT0pPdUNhQT0tLWZqTkNQUzBjNFUvcFhlWTA0YitETmc9PQ==--2f9e373be422d4fcc56c8d658afc55f1938a721e)](https://www.browserstack.com/automate/public-build/UzdFQU9hSW1FdjhLU3hDU0I3ZXF6WG1YSWp2TGRHaU9tYmhNT0pPdUNhQT0tLWZqTkNQUzBjNFUvcFhlWTA0YitETmc9PQ==--2f9e373be422d4fcc56c8d658afc55f1938a721e)
[![Ember Observer Score](http://emberobserver.com/badges/ember-bootstrap.svg)](http://emberobserver.com/addons/ember-bootstrap)
[![npm version](https://badge.fury.io/js/ember-bootstrap.svg)](https://badge.fury.io/js/ember-bootstrap)

An [ember-cli](http://www.ember-cli.com) addon for using [Bootstrap](http://getbootstrap.com/) 3 or 4 in Ember applications.

The addon includes the Bootstrap CSS (or Sass, Less) in your project (can be disabled). On top of that, it provides a set of native Ember components (no use of Bootstrap JavaScript!).</p>

*See [www.ember-bootstrap.com](http://www.ember-bootstrap.com/) for full documentation.*

## Installation

In your application's directory:

    ember install ember-bootstrap
    
This will install Bootstrap 4 and will use the currently installed preprocessor or none if one is not installed.
To switch Bootstrap version or preprocessor, see the [setup documentation](http://www.ember-bootstrap.com/#/getting-started/setup).

## Compatibility

ember-bootstrap works and is fully [tested](https://travis-ci.org/kaliber5/ember-bootstrap) with

* Ember.js 2.18+ / Ember CLI 2.18+
* Bootstrap 3 and 4.
* all modern evergreen browsers (Chrome, Firefox, Safari, Edge) and IE 11 (the latter requires the use of the [Babel polyfill](https://github.com/babel/ember-cli-babel#polyfill)). 
* FastBoot 1.0+ 
* jQuery-less builds (using [ember-native-dom-event-dispatcher](https://github.com/rwjblue/ember-native-dom-event-dispatcher)
or Ember 3.x)

This project follows [Semantic Versioning](http://semver.org/).

## Updates

See [CHANGELOG](CHANGELOG.md) for the list of all changes.

If you want to keep up to date with ember-bootstrap, you may want to [follow me on Twitter](https://twitter.com/simonihmig). 

## Author and collaborators

* [Simon Ihmig](https://github.com/simonihmig)
* [Stephen Vance](https://github.com/srvance)
* [Jeldrik Hanschke](https://github.com/jelhan)
* and many more [contributors](https://github.com/kaliber5/ember-bootstrap/graphs/contributors)

## Contributing

See the [Contributing](CONTRIBUTING.md) guide for details.

## Credits

Cross-browser testing provided by:

<a href="https://www.browserstack.com"><img height="70" src="docs/Browserstack-logo.svg" alt="BrowserStack"></a>

## Copyright and license

Code and documentation copyright 2019 [kaliber5](http://www.kaliber5.de) and contributors. Code released under [the MIT license](LICENSE.md).
